@@ -13,17 +13,17 @@ using namespace Kontact;
 #include <KontactInterface/Plugin>
 
 #include <KAboutData>
-#include <KLocalizedString>
-#include <QTextBrowser>
 #include <KConfigGroup>
-#include <QIcon>
 #include <KIconLoader>
+#include <KLocalizedString>
+#include <QIcon>
+#include <QTextBrowser>
 
+#include <KSharedConfig>
+#include <KWindowConfig>
 #include <QBoxLayout>
 #include <QLabel>
 #include <QPushButton>
-#include <KSharedConfig>
-#include <KWindowConfig>
 
 AboutDialog::AboutDialog(KontactInterface::Core *core)
     : KPageDialog(core)
@@ -34,8 +34,7 @@ AboutDialog::AboutDialog(KontactInterface::Core *core)
     button(QDialogButtonBox::Close)->setDefault(true);
     setModal(false);
     setFaceType(KPageDialog::List);
-    addAboutData(i18n("Kontact Container"), QStringLiteral("kontact"),
-                 KAboutData::applicationData());
+    addAboutData(i18n("Kontact Container"), QStringLiteral("kontact"), KAboutData::applicationData());
     QList<KontactInterface::Plugin *> plugins = mCore->pluginList();
     const QList<KontactInterface::Plugin *>::ConstIterator end = plugins.constEnd();
     QList<KontactInterface::Plugin *>::ConstIterator it = plugins.constBegin();
@@ -66,7 +65,7 @@ void AboutDialog::addAboutData(const QString &title, const QString &icon, const
     QIcon pixmap = QIcon::fromTheme(icon);
 
     QFrame *topFrame = new QFrame();
-    auto *pageItem = new KPageWidgetItem(topFrame, title);
+    auto pageItem = new KPageWidgetItem(topFrame, title);
     pageItem->setIcon(pixmap);
 
     addPage(pageItem);
@@ -85,8 +84,7 @@ void AboutDialog::addAboutData(const QString &title, const QString &icon, const
         text += QLatin1String("</p>");
 
         if (!about.shortDescription().isEmpty()) {
-            text += QLatin1String("<p>") + about.shortDescription() + QLatin1String("<br>")
-                    +about.copyrightStatement() + QLatin1String("</p>");
+            text += QLatin1String("<p>") + about.shortDescription() + QLatin1String("<br>") + about.copyrightStatement() + QLatin1String("</p>");
         }
 
         QString home = about.homepage();
@@ -99,11 +97,10 @@ void AboutDialog::addAboutData(const QString &title, const QString &icon, const
         QLabel *label = new QLabel(text, topFrame);
         label->setAlignment(Qt::AlignTop);
         label->setOpenExternalLinks(true);
-        label->setTextInteractionFlags(
-            Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard | Qt::LinksAccessibleByMouse);
+        label->setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard | Qt::LinksAccessibleByMouse);
         topLayout->addWidget(label);
 
-        auto *personView = new QTextBrowser(topFrame);
+        auto personView = new QTextBrowser(topFrame);
         personView->setReadOnly(true);
         topLayout->addWidget(personView, 1);
 
@@ -141,7 +138,7 @@ void AboutDialog::addAboutData(const QString &title, const QString &icon, const
                 text += formatPerson((*it).name(), (*it).emailAddress());
             }
         }
-        //krazy:excludeall=style (really need krazy conditional code sections)
+        // krazy:excludeall=style (really need krazy conditional code sections)
         text += i18n(
             "<br /><br />\
                      <i>This Free Software product was improved as part of a commercial project:</i>\
@@ -259,18 +256,17 @@ void AboutDialog::addLicenseText(const KAboutData &about)
     if (about.licenses().isEmpty()) {
         return;
     }
-    QPixmap pixmap = KIconLoader::global()->loadIcon(QStringLiteral("help-about"),
-                                                     KIconLoader::Desktop, 48);
+    QPixmap pixmap = KIconLoader::global()->loadIcon(QStringLiteral("help-about"), KIconLoader::Desktop, 48);
 
     const QString title = i18n("%1 License", about.displayName());
 
     QFrame *topFrame = new QFrame();
-    auto *page = new KPageWidgetItem(topFrame, title);
+    auto page = new KPageWidgetItem(topFrame, title);
     page->setIcon(QIcon(pixmap));
     addPage(page);
     QBoxLayout *topLayout = new QVBoxLayout(topFrame);
 
-    auto *textBrowser = new QTextBrowser(topFrame);
+    auto textBrowser = new QTextBrowser(topFrame);
     QString licenseStr;
     const QList<KAboutLicense> lstLicenses = about.licenses();
     for (const KAboutLicense &license : lstLicenses) {
