@@ -17,7 +17,7 @@ SidePaneBase::SidePaneBase(KontactInterface::Core *core, QWidget *parent)
     : QWidget(parent)
     , mCore(core)
 {
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 }
 
